==> haskell-conduit-1.2.6.2-1-armv7h.pkg.tar.xz: usr/share/haskell/haskell-conduit/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: conduit
version: 1.2.6.2
id: conduit-1.2.6.2-e9736ac2851958c9940f374454cdc4fe
key: condu_8Qe6INZ9CgpKoAjKuolIQy
license: MIT
maintainer: michael@snoyman.com
homepage: http://github.com/snoyberg/conduit
synopsis: Streaming data processing library.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/conduit>.
    .
    @conduit@ is a solution to the streaming data problem, allowing for production, transformation, and consumption of streams of data in constant memory. It is an alternative to lazy I\/O which guarantees deterministic resource handling, and fits in the same general solution space as @enumerator@\/@iteratee@ and @pipes@. For a tutorial, please visit <https://www.fpcomplete.com/user/snoyberg/library-documentation/conduit-overview>.
category: Data, Conduit
author: Michael Snoyman
exposed: True
exposed-modules:
    Data.Conduit Data.Conduit.List Data.Conduit.Internal
    Data.Conduit.Lift Data.Conduit.Internal.Fusion
    Data.Conduit.Internal.List.Stream
hidden-modules: Data.Conduit.Internal.Pipe
                Data.Conduit.Internal.Conduit
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/conduit-1.2.6.2
library-dirs: /usr/lib/ghc-7.10.3/site-local/conduit-1.2.6.2
data-dir: /usr/share/arm-linux-ghc-7.10.3/conduit-1.2.6.2
hs-libraries: HSconduit-1.2.6.2-8Qe6INZ9CgpKoAjKuolIQy
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    exceptions-0.8.2.1-8c1fe53cd5846ab1f6d4c58870c4f8d9
    lifted-base-0.2.3.6-26b5b3c50c56a653ba3c5b8bce492107
    mmorph-1.0.6-1a509ce4d7b5bdf9a92707e79b8069c6
    mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
    resourcet-1.1.7.2-b95e5d14f30eaa21587bc62eeb9aed0c
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    transformers-base-0.4.4-b65bc998c24abf50fea29d4891da9e32
haddock-interfaces: /usr/share/doc/haskell-conduit/html/conduit.haddock
haddock-html: /usr/share/doc/haskell-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-conduit-1.2.6.4-1-armv7h.pkg.tar.xz: usr/share/haskell/haskell-conduit/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: conduit
version: 1.2.6.4
id: conduit-1.2.6.4-0dfd87f475e845002478c37d3a30df1e
key: condu_Cam2rE5K61E3exYRjD0Ajx
license: MIT
maintainer: michael@snoyman.com
homepage: http://github.com/snoyberg/conduit
synopsis: Streaming data processing library.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/conduit>.
    .
    @conduit@ is a solution to the streaming data problem, allowing for production, transformation, and consumption of streams of data in constant memory. It is an alternative to lazy I\/O which guarantees deterministic resource handling, and fits in the same general solution space as @enumerator@\/@iteratee@ and @pipes@. For a tutorial, please visit <https://www.fpcomplete.com/user/snoyberg/library-documentation/conduit-overview>.
category: Data, Conduit
author: Michael Snoyman
exposed: True
exposed-modules:
    Data.Conduit Data.Conduit.List Data.Conduit.Internal
    Data.Conduit.Lift Data.Conduit.Internal.Fusion
    Data.Conduit.Internal.List.Stream
hidden-modules: Data.Conduit.Internal.Pipe
                Data.Conduit.Internal.Conduit
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/conduit-1.2.6.4
library-dirs: /usr/lib/ghc-7.10.3/site-local/conduit-1.2.6.4
data-dir: /usr/share/arm-linux-ghc-7.10.3/conduit-1.2.6.4
hs-libraries: HSconduit-1.2.6.4-Cam2rE5K61E3exYRjD0Ajx
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    exceptions-0.8.2.1-8c1fe53cd5846ab1f6d4c58870c4f8d9
    lifted-base-0.2.3.6-26b5b3c50c56a653ba3c5b8bce492107
    mmorph-1.0.6-1a509ce4d7b5bdf9a92707e79b8069c6
    mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
    resourcet-1.1.7.3-3e7ca03abacc332d28328c69bbd74cd4
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    transformers-base-0.4.4-b65bc998c24abf50fea29d4891da9e32
haddock-interfaces: /usr/share/doc/haskell-conduit/html/conduit.haddock
haddock-html: /usr/share/doc/haskell-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
